-- size of the block texture in pixels
BLOCK_SIZE = 4


-- table of block textures
BLOCK_TEXTURES = {
	love.graphics.newImage("res/blocks/stone.png"),
	love.graphics.newImage("res/blocks/core.png"),
}

-- make sure all the textures in BLOCK_TEXTURES stay pixely even when scaled
for i = 1, #BLOCK_TEXTURES do
	BLOCK_TEXTURES[i]:setFilter("nearest", "nearest")
end
	
-- these globals serve the double purpose of identifying the block type and
-- determining which texture to use from the BLOCK_TEXTURES table, an enumeration
-- would have been nice right about now . . .
PLAYER = 0
BLOCK_STONE = 1
BLOCK_CORE = 2
SENSOR_CORE = 100
SENSOR_MOUSE = 99

--[[

Base class for all blocks in the game

]]

Block = class("Block", Actor)
	
function Block:initialize(x, y, w, h, world, type)

	self.type = type
	self.w = w
	self.h = h
	
	Actor.initialize(self, x, y, w*4, h*4, world)
	
	self.fixture:setUserData({
		parent = self, 
		}) 
	
	self.spriteBatch = love.graphics.newSpriteBatch( BLOCK_TEXTURES[self.type], 
	9999,
	"dynamic"
	)
	
	self.sprites = {}
	
	for i = 0, w - 1 do
		for j = 0, h - 1 do
		local sprite = self.spriteBatch:add(i*BLOCK_SIZE - w*BLOCK_SIZE/2, 
											j*BLOCK_SIZE - h*BLOCK_SIZE/2)
		table.insert(self.sprites, sprite)
		end
	end
		

end

function Block:update(dt)

	Actor.update(self, dt)

end

function Block:draw()
--[[
	love.graphics.draw(
		BLOCK_TEXTURES[self.type],
		self.x,
		self.y,
		self.body:getAngle(),
		1.15,
		1.15,
		self.w / 2,
		self.h / 2
	)
]]
	--Actor.draw(self)
	
	love.graphics.draw( self.spriteBatch , self.x, self.y, self.body:getAngle(), 1 + .5/self.w, 1 + .5/self.h )
	

end

function Block:beginContact(fixture, coll)


end

function Block:endContact(fixture, coll)
    
end

function Block:preSolve(fixture, coll)
    
end

function Block:postSolve(fixture, coll)
    
end