--[[

"Solar System" class which holds the information for everything that the player
interacts with in the game. This class is basically what is commonly called the 
game class.

]]

System = class("System")

local gamera = require 'src/util/gamera'

function System:initialize()

	self.camera = gamera.new(-1000,-1000,2000,2000)
	self.camera:setScale(SCALE)
	
	self.world = love.physics.newWorld(0, 0, true)
	self.world:setCallbacks(beginContact, endContact, preSolve, postSolve)

	self.actors = {}
	
	self.player = Player(0, 0, self.world, self.camera)

	self.background = love.graphics.newImage('res/starField.jpg')
	self.background:setFilter("nearest", "nearest")

	table.insert(self.actors, Planet(0, 50, 20, 1000, self.world))
	
	
end

function System:update(dt)

	self.world:update(dt)
	
	self.player:update(dt)
	
	
	for i = 1, #self.actors do
		
		self.actors[i]:update(dt)
		
	end
	
	-- update the camera so the player is always exactly in the center of the screen
	self:camFollowPlayer()


end

function System:draw()

	-- we need to explicitly draw the background without any modifications
	-- that are applied by the camera
	local l,t,w,h = self.camera:getWindow()
	
	self.camera:draw(function()
	
	love.graphics.draw(self.background ,t - 100 ,t - 100 , 0, 1/6, 1/6, 0, 0)
	
	for i = 1, #self.actors do
		
		self.actors[i]:draw()
		
	end
	
	self.player:draw()
	
	end)

end

function System:camFollowPlayer()

	local playerAngle = self.player.body:getAngle()
	local cameraAngle = self.camera:getAngle()
	self.camera:setAngle(playerAngle)
	self.camera:setPosition(
		self.player.body:getX(), self.player.body:getY()
	)


end

function System:keyPressed(key, unicode)
	
	self.player:keyPressed(key, unicode)

end

--[[ 
a is the first fixture object in the collision.
b is the second fixture object in the collision.
coll is the contact object created.
]]

function beginContact(a, b, coll)
	a:getUserData().parent:beginContact(b, coll)
	b:getUserData().parent:beginContact(a, coll)
end

function endContact(a, b, coll)
    a:getUserData().parent:endContact(b, coll)
	b:getUserData().parent:endContact(a, coll)
end

function preSolve(a, b, coll)
    
end

function postSolve(a, b, coll)
    
end
